; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[command]
name="dfdf_z"
command = ~D, DF, F, D, DF, F, z
time = 20

[command]
name = "Super Fire Beam"
command = ~D, DF, F, y+z
time = 50

[command]
name= "bloodtide"
command = x, x, F, a, z
time = 50
;-| Special Motions |------------------------------------------------------

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[command]
name = "QCF_z"
command = ~D, DF, F, z

[command]
name = "DPK_Super"
command = D, DF, F, D, DF, F, c
time = 30

[command]
name = "Super Fire Beam"
command = ~D, F, D, F, z
time = 50

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "airdash"
command = F, /F
time = 2

[command]
name = "DU"
command= D, U
Time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "throw_p"
command = x+y
time = 5

[Command]
name = "throw_p"
command = y+z
time = 5

[Command]
name = "throw_p"
command = x+z
time = 5

[command]
name = "reverse"
command = a+c
time = 1
;-| Dir + Button |---------------------------------------------------------
[Command]
name = "superjump"
command = ~D, U

[Command]
name = "superjump"
command = ~DF, U

[Command]
name = "superjump"
command = ~DB, U

[Command]
name = "superjump"
command = ~D, UF

[Command]
name = "superjump"
command = ~D, UB

[Command]
name = "superjump"
command = ~DB, UF

[Command]
name = "superjump"
command = ~DF, UF

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "U"
command = U
time 7
;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 502
triggerall = command = "QCF_x"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
;-----------------------------------------------------------------------------
;Fire Beam Super
[State -1, Fire Beam Super]
type = ChangeState
value = 760
triggerall = var(30) = 0
triggerall = command = "Super Fire Beam"
triggerall = power >= 1000
;triggerall = statetype = A
trigger1 = statetype = S && ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 240
trigger5 = movecontact = 1
trigger5 = stateno = 230
trigger6 = movecontact = 1
trigger6 = stateno = 230
trigger7 = MoveContact = 1
trigger7 = stateno = 400
trigger8 = MoveContact = 1
trigger8 = stateno = 430
trigger9 = MoveContact = 1
trigger9 = stateno = 410
trigger10 = MoveContact = 1
trigger10 = stateno = 440
trigger11 = movecontact = 1
trigger11 = stateno = 210 ; ZEK
trigger12 = stateno = 100
trigger13 = movecontact = 1
trigger13 = stateno = 210
trigger14 = movecontact = 1
trigger14= stateno = 600
trigger15 = movecontact = 1
trigger15 = stateno = 610
trigger16 = movecontact = 1
trigger16= stateno = 615
trigger17 = movecontact = 1
trigger17 = stateno = 630
trigger18 = movecontact = 1
trigger18= stateno = 640
trigger19= movecontact = 1
trigger19 = stateno = 645
trigger20 = movecontact = 1
trigger20= stateno = 245
trigger21= movecontact = 1
trigger21 = stateno = 246
trigger22= movecontact = 1
trigger22 = stateno = 215
trigger23 = var(10) > 0
trigger23 = statetype = S
trigger23 = movecontact = 1
;----------------------------------------------------------------------
;---------------------------------------------------------------------------
;Super Scissor Kick Super
;[State -1, Light Kung Fu Palm]
;type = ChangeState
;value = 753
;triggerall = command = "DPK_Super"
;triggerall = statetype !=A
;triggerall = power >= 3000
;trigger1 = ctrl = 1
;trigger1 = statetype != A
;trigger2 = stateno = 200
;trigger2 = movecontact = 1
;trigger3 = stateno = 210
;trigger3 = movecontact = 1
;trigger4 = stateno = 215
;trigger4 = movecontact = 1
;trigger5 = stateno = 220
;trigger5 = movecontact = 1
;trigger6 = stateno = 225
;trigger6 = movecontact = 1
;trigger7 = stateno = 230
;trigger7 = movecontact = 1
;trigger8 = stateno = 240
;trigger8 = movecontact = 1
;trigger9 = stateno = 255
;trigger9 = movecontact = 1
;trigger10 = stateno = 300
;trigger10 = movecontact = 1
;trigger11 = stateno = 310
;trigger11 = movecontact = 1
;trigger12 = stateno = 320
;trigger12 = movecontact = 1
;trigger13 = stateno = 330
;trigger13 = movecontact = 1
;trigger14 = stateno = 340
;trigger14 = movecontact = 1
;trigger15 = stateno = 1200
;trigger15 = movecontact = 1
;trigger16 = stateno = 1300
;trigger16 = movecontact = 1
;trigger20 = stateno = 1201
;trigger20 = movecontact = 1
;trigger21 = stateno = 1204
;trigger21 = movecontact = 1
;trigger22 = stateno = 1207
;trigger22 = movecontact = 1
;---------------------------------------------------------------------------
;Fire Breath
[State -1, Fire Breath]
type = ChangeState
value = 7
triggerall = command = "QCF_y"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;Fierce Fire Wall
[State -1, Fierce Fire Wall]
type = ChangeState
value = 3
triggerall = command = "QCF_z"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;===========================================================================

;BloodTide Super
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 700
triggerall = command = "bloodtide"
triggerall = statetype !=A
triggerall = power >= 3000
trigger1 = ctrl = 1
trigger1 = statetype != A
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 215
trigger4 = movecontact = 1
trigger5 = stateno = 220
trigger5 = movecontact = 1
trigger6 = stateno = 225
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 255
trigger9 = movecontact = 1
trigger10 = stateno = 300
trigger10 = movecontact = 1
trigger11 = stateno = 310
trigger11 = movecontact = 1
trigger12 = stateno = 320
trigger12 = movecontact = 1
trigger13 = stateno = 330
trigger13 = movecontact = 1
trigger14 = stateno = 340
trigger14 = movecontact = 1
trigger15 = stateno = 1200
trigger15 = movecontact = 1
trigger16 = stateno = 1300
trigger16 = movecontact = 1
trigger20 = stateno = 1201
trigger20 = movecontact = 1
trigger21 = stateno = 1204
trigger21 = movecontact = 1
trigger22 = stateno = 1207
trigger22 = movecontact = 1
;---------------------------------------------------------------------------
;Super Scissor Kick Super
;[State -1, Light Kung Fu Palm]
;type = ChangeState
;value = 753
;triggerall = command = "DPK_Super"
;triggerall = statetype !=A
;triggerall = power >= 3000
;trigger1 = ctrl = 1
;trigger1 = statetype != A
;trigger2 = stateno = 200
;trigger2 = movecontact = 1
;trigger3 = stateno = 210
;trigger3 = movecontact = 1
;trigger4 = stateno = 215
;trigger4 = movecontact = 1
;trigger5 = stateno = 220
;trigger5 = movecontact = 1
;trigger6 = stateno = 225
;trigger6 = movecontact = 1
;trigger7 = stateno = 230
;trigger7 = movecontact = 1
;trigger8 = stateno = 240
;trigger8 = movecontact = 1
;trigger9 = stateno = 255
;trigger9 = movecontact = 1
;trigger10 = stateno = 300
;trigger10 = movecontact = 1
;trigger11 = stateno = 310
;trigger11 = movecontact = 1
;trigger12 = stateno = 320
;trigger12 = movecontact = 1
;trigger13 = stateno = 330
;trigger13 = movecontact = 1
;trigger14 = stateno = 340
;trigger14 = movecontact = 1
;trigger15 = stateno = 1200
;trigger15 = movecontact = 1
;trigger16 = stateno = 1300
;trigger16 = movecontact = 1
;trigger20 = stateno = 1201
;trigger20 = movecontact = 1
;trigger21 = stateno = 1204
;trigger21 = movecontact = 1
;trigger22 = stateno = 1207
;trigger22 = movecontact = 1
;---------------------------------------------------------------------------
;Fire Breath
[State -1, Fire Breath]
type = ChangeState
value = 7
triggerall = command = "QCF_y"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;Fierce Fire Wall
[State -1, Fierce Fire Wall]
type = ChangeState
value = 3
triggerall = command = "QCF_z"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
;Reversal
[state -1, Reversal]
type = changestate
value = 130
trigger1 = command = "reverse"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;===========================================================================

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Standing Light Punch]
type = ChangeState
value = 200
triggerall = var(30) = 0
triggerall = command != "holddown"
triggerall = command = "x"
;triggerall = statetype = S
trigger1 = statetype = S && ctrl = 1
;trigger2 = stateno = 206
trigger2 = stateno = 200
trigger3 = var(10) > 0
trigger3 = statetype = S
trigger3 = movecontact = 1
trigger4 = stateno = 230
trigger5 = var(10) > 0
trigger5 = statetype = S
trigger5 = movecontact = 1
trigger5 = stateno = 400
trigger6 = var(10) > 0
trigger6 = statetype = S
trigger6 = movecontact = 1


;---------------------------------------------------------------------------
;Standing Medium Punch
[State -1, Standing Medium Punch]
type = ChangeState
value = 210
triggerall = var(30) = 0
triggerall = command = "y"
triggerall = command != "holddown"
;triggerall = statetype = S
trigger1 = statetype = S && ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 230
trigger4 = MoveContact = 1
trigger4 = stateno = 400
trigger5 = MoveContact = 1
trigger5 = stateno = 430
trigger6 = stateno = 100
trigger7 = var(10) > 0
trigger7 = statetype = S
trigger7 = movecontact = 1

;----------------------------------------------------------------------------
;Standing Fierce Punch
[State -1, Standing Fierce Punch]
type = ChangeState
value = 215
triggerall = var(30) = 0
triggerall = command = "z"
triggerall = command != "holddown"
;triggerall = statetype = S
trigger1 = statetype = S && ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 240
trigger5 = movecontact = 1
trigger5 = stateno = 230
trigger6 = movecontact = 1
trigger6 = stateno = 400
trigger7 = MoveContact = 1
trigger7 = stateno = 430
trigger8 = MoveContact = 1
trigger8 = stateno = 410
trigger9 = MoveContact = 1
trigger9 = stateno = 440
trigger10 = MoveContact = 1
trigger10 = stateno = 410
trigger11 = movecontact = 1
trigger11 = stateno = 210 ; ZEK
trigger12 = stateno = 100
trigger13 = movecontact = 1
trigger13 = stateno = 210
trigger14 = var(10) > 0
trigger14 = statetype = S
trigger14 = movecontact = 1


;---------------------------------------------------------------------------
; Standing Short
[State -1, S.Short]
type = ChangeState
value = 230
triggerall = var(30) = 0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200 
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 400
;trigger5 = stateno = 201
;trigger5 = movecontact = 1
trigger5 = var(10) > 0
trigger5 = statetype = S
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_B Forward Kick
[State -1, S.Forward]
type = ChangeState
value = 240
triggerall = var(30) = 0
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 400
trigger6 = MoveContact = 1
trigger6 = stateno = 430
trigger7 = MoveContact = 1
trigger7 = stateno = 410
trigger8 = MoveContact = 1
trigger8 = stateno = 400
trigger9 = stateno = 100
trigger10 = var(10) > 0
trigger10 = statetype = S
trigger10 = movecontact = 1
;---------------------------------------------------------------------------
;Standing Fierce kick
[State -1, Standing Fierce kick]
type = ChangeState
value = 245
triggerall = var(30) = 0
triggerall = command = "c"
triggerall = command != "holddown"
;triggerall = statetype = S
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = p2dist x <= 10
trigger1 = statetype = S && ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 240
trigger5 = movecontact = 1
trigger5 = stateno = 230
trigger6 = movecontact = 1
trigger6 = stateno = 230
trigger7 = MoveContact = 1
trigger7 = stateno = 400
trigger8 = MoveContact = 1
trigger8 = stateno = 430
trigger9 = MoveContact = 1
trigger9 = stateno = 410
trigger10 = MoveContact = 1
trigger10 = stateno = 440
trigger11 = movecontact = 1
trigger11 = stateno = 210 ; ZEK
trigger12 = stateno = 100
trigger13 = movecontact = 1
trigger13 = stateno = 210
trigger14 = var(10) > 0
trigger14 = statetype = S
trigger14 = movecontact = 1
;---------------------------------------------------------------------------
;Standing Fierce kick
[State -1, Standing Fierce kick]
type = ChangeState
value = 246
triggerall = var(30) = 0
triggerall = command = "c"
triggerall = command != "holddown"
;triggerall = statetype = S
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = statetype = S && ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 240
trigger5 = movecontact = 1
trigger5 = stateno = 230
trigger6 = movecontact = 1
trigger6 = stateno = 230
trigger7 = MoveContact = 1
trigger7 = stateno = 400
trigger8 = MoveContact = 1
trigger8 = stateno = 430
trigger9 = MoveContact = 1
trigger9 = stateno = 410
trigger10 = MoveContact = 1
trigger10 = stateno = 440
trigger11 = movecontact = 1
trigger11 = stateno = 210 ; ZEK
trigger12 = stateno = 100
trigger13 = movecontact = 1
trigger13 = stateno = 210
trigger14 = var(10) > 0
trigger14 = statetype = S
trigger14 = movecontact = 1
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Crouch Light Punch
[State -1, Crouch LP]
type = ChangeState
value = 400
triggerall = var(30) = 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger3 = time >= 5
trigger3 = stateno = 230
trigger4 = time >= 5
trigger4 = stateno = 430
trigger5 = var(10) > 0
trigger5 = movecontact = 1
trigger5 = statetype != A

;---------------------------------------------------------------------------
;Crouch Medium Punch
[State -1, Crouch MP]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = var(30) = 0
triggerall = command = "holddown"
;triggerall = statetype = C
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 400
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 430
trigger6 = movecontact = 1
trigger6 = stateno = 240 ; ZEK
trigger7 = stateno = 440
trigger8 = var(10) > 0
trigger8 = movecontact = 1
trigger8 = statetype != A
;---------------------------------------------------------------------------
;Crouch Fierce Punch
[State -1, Crouch FP]
type = ChangeState
value = 415
triggerall = command = "z"
triggerall = var(30) = 0
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 400
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 430
trigger6 = movecontact = 1
trigger6 = stateno = 210
trigger7 = movecontact = 1
trigger7 = stateno = 410
trigger8 = movecontact = 1
trigger8 = stateno = 240
trigger9 = movecontact = 1
trigger9 = stateno = 440
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = movecontact = 1
trigger11 = stateno = 208 ; ZEK
trigger12 = stateno = 100
trigger13 = stateno = 215
trigger14 = movecontact = 1
trigger14 = stateno = 210
trigger15 = var(10) > 0
trigger15 = movecontact = 1
trigger15 = statetype != A

;--------------------------------------------------------------------------
;Crouch Light Kick
[State -1, Crouch LK]
type = ChangeState
value = 430
triggerall = var(30) = 0
triggerall = command = "a"
triggerall = command = "holddown"
;triggerall = statetype = C
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = time >= 5
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 400
trigger4 = time >= 5
trigger4 = stateno = 230
trigger5 = time >= 5
trigger5 = stateno = 206
trigger6 = movecontact = 1
trigger6 = stateno = 405
trigger7 = stateno = 100
trigger8 = var(10) > 0
trigger8 = movecontact = 1
trigger8 = statetype != A


;---------------------------------------------------------------------------
;Crouch Medium Kick
[State -1, Crouch MK]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = var(30) = 0
triggerall = command = "holddown"
;triggerall = statetype = C
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 230
trigger4 = movecontact = 1
trigger4 = stateno = 400
trigger5 = movecontact = 1
trigger5 = stateno = 430
trigger6 = movecontact = 1
trigger6 = stateno = 210
trigger7 = movecontact = 1
trigger7 = stateno = 410
trigger8 = movecontact = 1
trigger8 = stateno = 211
trigger9 = movecontact = 1
trigger9 = stateno = 208 ; ZEK
trigger10 = stateno = 100
trigger11 = var(10) > 0
trigger11 = movecontact = 1
trigger11 = statetype != A

;---------------------------------------------------------------------------]
;Crouch Fierce Kick
[State -1, Crouch FK]
type = ChangeState
value = 445
triggerall = command = "c"
triggerall = var(30) = 0
triggerall = command = "holddown"
;triggerall = statetype = C
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 230
trigger4 = movecontact = 1
trigger4 = stateno = 400
trigger5 = movecontact = 1
trigger5 = stateno = 230
trigger6 = movecontact = 1
trigger6 = stateno = 210
trigger7 = movecontact = 1
trigger7 = stateno = 240
trigger8 = movecontact = 1
trigger8 = stateno = 410
trigger9 = movecontact = 1
trigger9 = stateno = 208; ZEK
trigger10 = movecontact = 1
trigger10 = stateno = 440
trigger11 = movecontact = 1
trigger11 = stateno = 410
trigger12 = movecontact = 1
trigger12 = stateno = 210
trigger13 = stateno = 100
trigger14 = var(10) > 0
trigger14 = movecontact = 1
trigger14 = statetype != A

;--------------------------------------------------------------------------
;Jumping light punch
[State -1, jump LP]
type = ChangeState
value = 600
triggerall = var(30) = 0
triggerall = command = "x"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600 || stateno = 630
trigger2 = movecontact = 1
trigger3 = var(10) > 0
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Jumping Medium Punch
[State -1, Jump MP]
type = ChangeState
value = 610
triggerall = var(30) = 0
triggerall = command = "y"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600 || stateno = 630 || stateno = 640
trigger2 = movecontact = 1
trigger3 = var(10) > 0
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Jumping Fierce Punch
[State -1, Jump FP]
type = ChangeState
value = 615
triggerall = var(30) = 0
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640 
trigger2 = movecontact = 1
trigger3 = var(10) > 0
trigger3 = movecontact = 1



;Jump_A Short Neutral (done)
[State -1, J.Short]
type = ChangeState
value = 630
triggerall = var(30) = 0
triggerall = command = "a"
triggerall = Statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600 && movecontact = 1
trigger3 = var(10) > 0
trigger3 = movecontact = 1


;---------------------------------------------------------------------------
;Jump_B Forward Kick
[State -1, J.Forward]
type = ChangeState
value = 640
triggerall = var(30) = 0
triggerall = command = "b"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600 || stateno = 630 || stateno = 610 
trigger2 = movecontact = 1
trigger3 = var(10) > 0
trigger3 = movecontact = 1


;Jump_C RoundHouse Non-Neutral (done)
[State -1, J.Roundhouse NN]
type = ChangeState
value = 645
triggerall = var(30) = 0
triggerall = command = "c"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600 || stateno = 630 || stateno = 640 || stateno = 610 
trigger2 = movecontact = 1
trigger3 = var(10) > 0
trigger3 = movecontact = 1

;Guard Push (Standing)
[State -1, Guard Push]
type = ChangeState
value = 910
triggerall = Var(59) != 1 ;AI doesn't do this move
triggerall = command = "throw_p"
triggerall = statetype = S
trigger1 = stateno = [150,153]

;---------------------------------------------------------------------------
;Guard Push (Crouching)
[State -1, Guard Push]
type = ChangeState
value = 915
triggerall = Var(59) != 1 ;AI doesn't do this move
triggerall = command = "throw_p"
triggerall = statetype = C
trigger1 = stateno = [150,153]

;---------------------------------------------------------------------------
;Guard Push (Air)
[State -1, Guard Push]
type = ChangeState
value = 920
triggerall = Var(59) != 1 ;AI doesn't do this move
triggerall = command = "throw_p"
triggerall = statetype = A
trigger1 = stateno = [154,155]

[State -1, Run Back]
type = ChangeState
value = 999
triggerall = var(20) = 0
trigger1 = command = "superjump"
trigger1 = statetype != A
trigger1 = ctrl

;Aerial Rave Jump
[State -1]
type = ChangeState
value = 998
triggerall = var(30) = 0
triggerall = command = "holdup"
trigger1 = movecontact = 1
trigger1 = stateno = 350
trigger2 = stateno = 415 || stateno = 209 || stateno = 220 || stateno = 230 || stateno = 225 || stateno = 420 || stateno = 425 || stateno = 270 || stateno = 245 || stateno =246
trigger2 = movecontact = 1
